#ifndef H_CDW_MKISOFS_OPTIONS
#define H_CDW_MKISOFS_OPTIONS

#include "main.h"
#include "cdw_form.h"
#include "cdw_iso9660.h"

#define CDW_MKISOFS_ISO_MAIN_OPTIONS_N_FIELDS  16


cdw_rv_t cdw_mkisofs_options_form(cdw_form_t *cdw_form, void *task, int first_col, int second_col, int width_wide, int width_narrow);
cdw_rv_t cdw_mkisofs_options_validate(cdw_iso9660_t *iso, int *fi);
cdw_rv_t cdw_mkisofs_options_save(cdw_form_t *cdw_form, cdw_iso9660_t *iso);



#endif /* H_CDW_MKISOFS_OPTIONS */
